#ifndef _KGR_PATCH_BSC1012852_LOCAL_H
#define _KGR_PATCH_BSC1012852_LOCAL_H

#include <linux/tipc_config.h>
#include <linux/netdevice.h>

#define TIPC_MEDIA_ADDR_SIZE	20
#define MAX_NODES 4096
#define WSIZE 32
#define MAX_BEARERS	2
#define MAX_ETH_MEDIA		MAX_BEARERS
#define TIPC_MEDIA_TYPE_ETH	1

/*
 * Fix CVE-2016-8632
 *  +new define
 */
/* minimum bearer MTU */
#define TIPC_MIN_BEARER_MTU    100     /* MAX_H_SIZE + INT_H_SIZE */

struct tipc_media_addr {
	u8 value[TIPC_MEDIA_ADDR_SIZE];
	u8 media_id;
	u8 broadcast;
};

struct tipc_node_map {
	u32 count;
	u32 map[MAX_NODES / WSIZE];
};

struct tipc_bearer {
	void *usr_handle;			/* initalized by media */
	u32 mtu;				/* initalized by media */
	struct tipc_media_addr addr;		/* initalized by media */
	char name[TIPC_MAX_BEARER_NAME];
	struct tipc_media *media;
	struct tipc_media_addr bcast_addr;
	u32 priority;
	u32 window;
	u32 tolerance;
	u32 identity;
	struct tipc_link_req *link_req;
	int active;
	char net_plane;
	struct tipc_node_map nodes;
};

struct eth_media {
	struct tipc_bearer *bearer;
	struct net_device *dev;
	struct packet_type tipc_packet_type;
	struct work_struct setup;
	struct work_struct cleanup;
};

/*
 * Fix CVE-2016-8632
 *  +new function
 */
/* check if device MTU is too low for a TIPC bearer */
static inline bool kgr_tipc_mtu_bad(struct net_device *dev, unsigned int reserve)
{
	if (dev->mtu >= TIPC_MIN_BEARER_MTU + reserve)
		return false;
	netdev_warn(dev, "MTU too low for tipc bearer\n");
	return true;
}

#endif
